@@ -19,22 +19,22 @@ def parse_args() -> argparse.Namespace:
         "-i",
         "--ignore-pep8",
         action="store_true",
-        help="ignore PEP8 module naming standards",
+        help="ignore PEP8 package naming standards",
     )
-    parser.add_argument("modules", nargs="+", type=str, help="module(s) to be created")
-    module_settings = parser.add_argument_group("module settings")
-    module_settings.add_argument(
+    parser.add_argument("packages", nargs="+", type=str, help="package(s) to be created")
+    package_settings = parser.add_argument_group("package settings")
+    package_settings.add_argument(
         "-a",
         "--add",
         nargs="*",
         type=str,
-        help="additional *.py files to be created inside module(s)",
+        help="additional *.py files to be created inside package(s)",
     )
-    module_settings.add_argument(
+    package_settings.add_argument(
         "-e",
         "--executable",
         action="store_true",
-        help='create executable module(s) (same as "--add __main__")',
+        help='create executable package(s) (same as "--add __main__")',
     )
 
     return parser.parse_args()
